==> Google-Ads-GoogleAds-Client-23.0.0.tar.gz: Google-Ads-GoogleAds-Client-23.0.0/lib/Google/Ads/GoogleAds/V17/Enums/ChangeStatusResourceTypeEnum.pm <==
# Copyright 2020, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V17::Enums::ChangeStatusResourceTypeEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED           => "UNSPECIFIED",
  UNKNOWN               => "UNKNOWN",
  AD_GROUP              => "AD_GROUP",
  AD_GROUP_AD           => "AD_GROUP_AD",
  AD_GROUP_CRITERION    => "AD_GROUP_CRITERION",
  CAMPAIGN              => "CAMPAIGN",
  CAMPAIGN_CRITERION    => "CAMPAIGN_CRITERION",
  FEED                  => "FEED",
  FEED_ITEM             => "FEED_ITEM",
  AD_GROUP_FEED         => "AD_GROUP_FEED",
  CAMPAIGN_FEED         => "CAMPAIGN_FEED",
  AD_GROUP_BID_MODIFIER => "AD_GROUP_BID_MODIFIER",
  SHARED_SET            => "SHARED_SET",
  CAMPAIGN_SHARED_SET   => "CAMPAIGN_SHARED_SET",
  ASSET                 => "ASSET",
  CUSTOMER_ASSET        => "CUSTOMER_ASSET",
  CAMPAIGN_ASSET        => "CAMPAIGN_ASSET",
  AD_GROUP_ASSET        => "AD_GROUP_ASSET",
  COMBINED_AUDIENCE     => "COMBINED_AUDIENCE"
];

1;

==> Google-Ads-GoogleAds-Client-25.0.0.tar.gz: Google-Ads-GoogleAds-Client-25.0.0/lib/Google/Ads/GoogleAds/V17/Enums/ChangeStatusResourceTypeEnum.pm <==
# Copyright 2020, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V17::Enums::ChangeStatusResourceTypeEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED           => "UNSPECIFIED",
  UNKNOWN               => "UNKNOWN",
  AD_GROUP              => "AD_GROUP",
  AD_GROUP_AD           => "AD_GROUP_AD",
  AD_GROUP_CRITERION    => "AD_GROUP_CRITERION",
  CAMPAIGN              => "CAMPAIGN",
  CAMPAIGN_CRITERION    => "CAMPAIGN_CRITERION",
  FEED                  => "FEED",
  FEED_ITEM             => "FEED_ITEM",
  AD_GROUP_FEED         => "AD_GROUP_FEED",
  CAMPAIGN_FEED         => "CAMPAIGN_FEED",
  AD_GROUP_BID_MODIFIER => "AD_GROUP_BID_MODIFIER",
  SHARED_SET            => "SHARED_SET",
  CAMPAIGN_SHARED_SET   => "CAMPAIGN_SHARED_SET",
  ASSET                 => "ASSET",
  CUSTOMER_ASSET        => "CUSTOMER_ASSET",
  CAMPAIGN_ASSET        => "CAMPAIGN_ASSET",
  AD_GROUP_ASSET        => "AD_GROUP_ASSET",
  COMBINED_AUDIENCE     => "COMBINED_AUDIENCE",
  ASSET_GROUP           => "ASSET_GROUP"
];

1;
